@@ -203,6 +203,7 @@ var ModalDialog = GObject.registerClass({
 
         this._state = State.CLOSED;
         this._hasModal = false;
+        this._grab = null;
         this._pushModalDelaySource = 0;
         this._pushModalWatchId = 0;
         this._pushModalSource = 0;
@@ -439,8 +440,16 @@ var ModalDialog = GObject.registerClass({
             return;
         }
 
-        Main.popModal(this, timestamp);
+        if (this._grab.get_seat_state !== undefined) {
+            // gnome-shell 42 and newer
+            Main.popModal(this._grab, timestamp);
+        }
+        else {
+            Main.popModal(this, timestamp);
+        }
+        this._grab = null;
         this._hasModal = false;
+
         this._lightbox.reactive = false;
     }
 
@@ -458,21 +467,30 @@ var ModalDialog = GObject.registerClass({
             params['timestamp'] = timestamp;
         }
 
-        if (!Main.pushModal(this, params)) {
-            return;
+        let grab = Main.pushModal(this, params);
+        if (grab.get_seat_state !== undefined) {
+            // gnome-shell 42 and newer
+            if (grab.get_seat_state() === Clutter.GrabState.NONE) {
+                Main.popModal(grab);
+                return false;
+            }
         }
 
-        this._disconnectPushModalSignals();
+        this._grab = grab;
+        Main.layoutManager.emit('system-modal-opened');
+
         this._hasModal = true;
+        this._disconnectPushModalSignals();
         this._lightbox.reactive = true;
 
-        global.stage.set_key_focus(this._lightbox);
+        // global.stage.set_key_focus(this._lightbox);
+        this._lightbox.grab_key_focus();
 
         if (!this._keyFocusOutId) {
             this._keyFocusOutId = this._lightbox.connect('key-focus-out', this._onKeyFocusOut.bind(this));
         }
 
-        Main.layoutManager.emit('system-modal-opened');
+        return true;
     }
 
     _onDestroy() {
